# mdk-python: MDK implementation in Python

mdk-python provides functionality for writing MUGEN character code in Python. The code generated by mdk-python compiles first to MTL, which is then compiled (via the `mtl-mugen` Python package) to CNS code.

mdk-python exposes a majority of the extensions to the CNS syntax handled by MTL, including named variables, named state definitions, and reusable functions.

For more details on how to use the library, see [this document](https://github.com/ZiddiaMUGEN/MDK/blob/main/mdk-python/TUTORIAL.md).